struct PrecomputedValues<P: ParameterSet> {
A_hat: NttMatrix<BaseField, P::K, P::L>,
t1_2d_hat: NttVector<BaseField, P::K>,
tr: Array<u8, U64>,
}Expand description
Cached values derived from rho and t1 at key construction time to avoid re-expanding them
when verifying signatures.
Fields
A_hat: NttMatrix<BaseField, P::K, P::L>Expanded public matrix in NTT domain.
t1_2d_hat: NttVector<BaseField, P::K>2ᵈ ⋅ t1 which can be reused in signature verification.
tr: Array<u8, U64>Hash of the encoded public key, used to bind messages to the key this was precomputed from.
Implementations
Sourceimpl<P: MlDsaParams> PrecomputedValues<P>
impl<P: MlDsaParams> PrecomputedValues<P>